==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/SwitchNodeGraph.h <==
// class soot.dava.toolkits.base.finders.SwitchNodeGraph

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class afc91c83fa0f9ccd soot_dava_toolkits_base_finders_SwitchNodeGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_
#define _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getBody$5184fdb9865818ce(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getHeads$e2893bcf27fe8f99(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getPredsOf$1d1efff5d341523f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getSuccsOf$51ae3c0a375c9961(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getTails$a9060bae945c433f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
extern jint _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getBody$5184fdb9865818ce;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getHeads$e2893bcf27fe8f99;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getPredsOf$1d1efff5d341523f;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getSuccsOf$51ae3c0a375c9961;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getTails$a9060bae945c433f;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods {
	struct _jc_object	*(*getBody$5184fdb9865818ce)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
	struct _jc_object	*(*getHeads$e2893bcf27fe8f99)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
	struct _jc_object	*(*getPredsOf$1d1efff5d341523f)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getSuccsOf$51ae3c0a375c9961)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getTails$a9060bae945c433f)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods	soot_dava_toolkits_base_finders_SwitchNodeGraph;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs {
	struct _jc_java_util_LinkedList$object	*body;
	struct _jc_java_util_LinkedList$object	*heads;
	struct _jc_java_util_LinkedList$object	*tails;
	struct _jc_java_util_HashMap$object	*binding;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs {
    _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs	soot_dava_toolkits_base_finders_SwitchNodeGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs	soot_dava_toolkits_base_finders_SwitchNodeGraph;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object {
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SwitchNodeGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/SwitchNodeGraph.h <==
// class soot.dava.toolkits.base.finders.SwitchNodeGraph

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class afc91c83fa0f9ccd soot_dava_toolkits_base_finders_SwitchNodeGraph

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_
#define _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_LinkedList$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getBody$5184fdb9865818ce(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getHeads$e2893bcf27fe8f99(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getPredsOf$1d1efff5d341523f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getSuccsOf$51ae3c0a375c9961(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$getTails$a9060bae945c433f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getBody$5184fdb9865818ce;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getHeads$e2893bcf27fe8f99;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getPredsOf$1d1efff5d341523f;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getSuccsOf$51ae3c0a375c9961;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$getTails$a9060bae945c433f;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$iterator$3cc91493d50f531c;
extern _jc_method _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods {
	struct _jc_object	*(*getBody$5184fdb9865818ce)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getHeads$e2893bcf27fe8f99)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPredsOf$1d1efff5d341523f)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSuccsOf$51ae3c0a375c9961)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getTails$a9060bae945c433f)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vmethods	soot_dava_toolkits_base_finders_SwitchNodeGraph;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs {
	struct _jc_java_util_LinkedList$object	*body;
	struct _jc_java_util_LinkedList$object	*heads;
	struct _jc_java_util_LinkedList$object	*tails;
	struct _jc_java_util_HashMap$object	*binding;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs {
    _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_refs	soot_dava_toolkits_base_finders_SwitchNodeGraph;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$sub_nonrefs	soot_dava_toolkits_base_finders_SwitchNodeGraph;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$object {
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$vtype _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_SwitchNodeGraph, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_SwitchNodeGraph$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_SwitchNodeGraph_H_ */
